% Auto-generated chapter 24 for muslim
% Hadiths in this chapter: 41

\hadithdefcmd{muslim}{4163}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ حَمَلْتُ عَلَى فَرَسٍ عَتِيقٍ فِي سَبِيلِ اللَّهِ فَأَضَاعَهُ صَاحِبُهُ فَظَنَنْتُ أَنَّهُ بَائِعُهُ بِرُخْصٍ فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ لاَ تَبْتَعْهُ وَلاَ تَعُدْ فِي صَدَقَتِكَ فَإِنَّ الْعَائِدَ فِي صَدَقَتِهِ كَالْكَلْبِ يَعُودُ فِي قَيْئِهِ ‏"‏ ‏.‏\hadithno{4163}\hadithtrans{Umar b. Khattab (Allah be pleased with him) reported:I donated a pedigree horse in the path of Allah. Its possessor made it languish. I thought that he would sell it at a cheap price. I asked Allah's Messenger (ﷺ) about it, whereupon he said: Don't buy it and do not get back your charity, for one who gets back the charity is like a dog who swallows its vomit}}
\hadithdefcmd{muslim}{4164}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - عَنْ مَالِكِ، بْنِ أَنَسٍ بِهَذَا الإِسْنَادِ وَزَادَ ‏ "‏ لاَ تَبْتَعْهُ وَإِنْ أَعْطَاكَهُ بِدِرْهَمٍ ‏"‏ ‏.‏\hadithno{4164}\hadithtrans{This hadith has been narrated on the authority of Malik b. Anas with the same chain of transmitters but with this addition:" Don't buy that even if he gives you for one dirham}}
\hadithdefcmd{muslim}{4165}{حَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامَ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا رَوْحٌ، - وَهُوَ ابْنُ الْقَاسِمِ - عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عُمَرَ، أَنَّهُ حَمَلَ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ فَوَجَدَهُ عِنْدَ صَاحِبِهِ وَقَدْ أَضَاعَهُ وَكَانَ قَلِيلَ الْمَالِ فَأَرَادَ أَنْ يَشْتَرِيَهُ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ ‏ "‏ لاَ تَشْتَرِهِ وَإِنْ أُعْطِيتَهُ بِدِرْهَمٍ فَإِنَّ مَثَلَ الْعَائِدِ فِي صَدَقَتِهِ كَمَثَلِ الْكَلْبِ يَعُودُ فِي قَيْئِهِ ‏"‏ ‏.‏\hadithno{4165}\hadithtrans{Zaid b. Aslam reported on the authority of his father that 'Umar (Allah be pleased with him) donated a horse in the path of Allah. He found that it had languished in the hand of its possessor, and he was a man of meagre resources He (Hadrat 'Umar) intended to buy it. He came to Allah's Messenger (ﷺ) and made a mention of that to him, whereupon he said:Don't buy that even if you get it for a dirham for he who gets back the charity is like a dog which swallows its vomit}}
\hadithdefcmd{muslim}{4166}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ زَيْدِ بْنِ أَسْلَمَ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ مَالِكٍ وَرَوْحٍ أَتَمُّ وَأَكْثَرُ ‏.‏\hadithno{4166}\hadithtrans{This hadith has been narrated on the authority of Zaid b. Aslam with the same chain of transmitters but with this (change) that the hadith transmitted on the authority of Malik and Rauh (he was the son of Qisirn) is more complete and lengthy}}
\hadithdefcmd{muslim}{4167}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، بْنَ الْخَطَّابِ حَمَلَ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ فَوَجَدَهُ يُبَاعُ فَأَرَادَ أَنْ يَبْتَاعَهُ فَسَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ لاَ تَبْتَعْهُ وَلاَ تَعُدْ فِي صَدَقَتِكَ ‏"‏ ‏.‏\hadithno{4167}\hadithtrans{Ibn 'Umar reported that 'Umar b. al-Khattib (Allah be pleased with him) donated a horse in the path of Allah and (later on) he found it being sold, and he decided to buy that. He asked the Messenger of Allah (ﷺ) about it. whereupon he (the Holy prophet) said:Don't buy that and do not get back what you gave in charity}}
\hadithdefcmd{muslim}{4168}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، رُمْحٍ جَمِيعًا عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا الْمُقَدَّمِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى قَالاَ حَدَّثَنَا يَحْيَى، وَهُوَ الْقَطَّانُ ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، كِلاَهُمَا عَنْ نَافِعٍ، عَنِ ابْنِ، عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ مَالِكٍ ‏.‏\hadithno{4168}\hadithtrans{This hadith has been narrated on the authority of Ibn Umar through another chain of transmitters}}
\hadithdefcmd{muslim}{4169}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لِعَبْدٍ - قَالَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، حَمَلَ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ ثُمَّ رَآهَا تُبَاعُ فَأَرَادَ أَنْ يَشْتَرِيَهَا فَسَأَلَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَعُدْ فِي صَدَقَتِكَ يَا عُمَرُ ‏"‏ ‏.‏\hadithno{4169}\hadithtrans{Salim reported from Ibn Umar (Allah be pleased with them) that 'Umar donated a horse in the path of Allah and then found it being sold, and he decided to buy that. He asked Allah's Apostle (ﷺ) about it, whereupon Allah's Messenger (ﷺ) said:Umar, do not get back what you gave as charity}}
\hadithdefcmd{muslim}{4170}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالاَ أَخْبَرَنَا عِيسَى، بْنُ يُونُسَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ أَبِي جَعْفَرٍ، مُحَمَّدِ بْنِ عَلِيٍّ عَنِ ابْنِ الْمُسَيَّبِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الَّذِي يَرْجِعُ فِي صَدَقَتِهِ كَمَثَلِ الْكَلْبِ يَقِيءُ ثُمَّ يَعُودُ فِي قَيْئِهِ فَيَأْكُلُهُ ‏"‏ ‏.‏\hadithno{4170}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported Allah's Apostle (ﷺ) having said this:He who gets back his charity is like a dog which vomits, and then returns to that and eats it}}
\hadithdefcmd{muslim}{4171}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنِ الأَوْزَاعِيِّ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ عَلِيِّ بْنِ الْحُسَيْنِ، يَذْكُرُ بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{4171}\hadithtrans{This hadith is also reported through another chain}}
\hadithdefcmd{muslim}{4172}{وَحَدَّثَنِيهِ حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا حَرْبٌ، حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ أَبِي كَثِيرٍ - حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَمْرٍو، أَنَّ مُحَمَّدَ ابْنَ فَاطِمَةَ بِنْتِ رَسُولِ اللَّهِ، صلى الله عليه وسلم حَدَّثَهُ بِهَذَا الإِسْنَادِ، نَحْوَ حَدِيثِهِمْ ‏.‏\hadithno{4172}\hadithtrans{A hadith like this is reported on the authority of Muhammad son of Fatima (Allah be pleased with her) daughter of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{4173}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - وَهُوَ ابْنُ الْحَارِثِ - عَنْ بُكَيْرٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّمَا مَثَلُ الَّذِي يَتَصَدَّقُ بِصَدَقَةٍ ثُمَّ يَعُودُ فِي صَدَقَتِهِ كَمَثَلِ الْكَلْبِ يَقِيءُ ثُمَّ يَأْكُلُ قَيْأَهُ ‏"‏ ‏.‏\hadithno{4173}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported:I heard Allah's Messenger (ﷺ) say: The similitude of one who gives a charity and then gets it back is like that of a dog which vomits and then eats its vomit}}
\hadithdefcmd{muslim}{4174}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْعَائِدُ فِي هِبَتِهِ كَالْعَائِدِ فِي قَيْئِهِ ‏"‏ ‏.‏\hadithno{4174}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported Allah's Apostle (ﷺ) as saying:One who gets back the gift is like one who eats vomit}}
\hadithdefcmd{muslim}{4175}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4175}\hadithtrans{This hadith has been narrated on the authority of Qatada with the same chain of transmitters}}
\hadithdefcmd{muslim}{4176}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْمَخْزُومِيُّ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ اللَّهِ، بْنُ طَاوُسٍ عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَائِدُ فِي هِبَتِهِ كَالْكَلْبِ يَقِيءُ ثُمَّ يَعُودُ فِي قَيْئِهِ ‏"‏ ‏.‏\hadithno{4176}\hadithtrans{Abdullah b. Tawus reported on the authority of his father who reported from Ibn Abas (Allah be pleased with them) who reported from Allah's Messenger 'may peace be upon him) that he said:One who gets back his gift is like a dog which vomits and then swallows that vomit}}
\hadithdefcmd{muslim}{4177}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ، الرَّحْمَنِ وَعَنْ مُحَمَّدِ بْنِ النُّعْمَانِ بْنِ بَشِيرٍ، يُحَدِّثَانِهِ عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّهُ قَالَ إِنَّ أَبَاهُ أَتَى بِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي نَحَلْتُ ابْنِي هَذَا غُلاَمًا كَانَ لِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَكُلَّ وَلَدِكَ نَحَلْتَهُ مِثْلَ هَذَا ‏"‏ ‏.‏ فَقَالَ لاَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَارْجِعْهُ ‏"‏ ‏.‏\hadithno{4177}\hadithtrans{Nu'man b. Bashir reported that his father brought him to Allah's Messenger (ﷺ) and said:I have donated this slave of mine to my son. Allah's Messenger (ﷺ) said: Have you donated to every one of your sons (a slave) like this? He said: No. Thereupon Allah's Messenger (may peace he upon him) said: Then take him back}}
\hadithdefcmd{muslim}{4178}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ، عَبْدِ الرَّحْمَنِ وَمُحَمَّدِ بْنِ النُّعْمَانِ عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ أَتَى بِي أَبِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي نَحَلْتُ ابْنِي هَذَا غُلاَمًا ‏.‏ فَقَالَ ‏"‏ أَكُلَّ بَنِيكَ نَحَلْتَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَارْدُدْهُ ‏"‏ ‏.‏\hadithno{4178}\hadithtrans{Nu'man b. Bashir reported:My father brought me to Allah's Messenger (ﷺ) and said: I have donated this slave to my son. whereupon he said: Have you made (such) donation to every one or your sons? He said: No. Thereupon he (the-Holy Prophet) said: Then take him back}}
\hadithdefcmd{muslim}{4179}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، عَنِ ابْنِ عُيَيْنَةَ، ح وَحَدَّثَنَا قُتَيْبَةُ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ، وَهْبٍ قَالَ أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ أَمَّا يُونُسُ وَمَعْمَرٌ فَفِي حَدِيثِهِمَا ‏"‏ أَكُلَّ بَنِيكَ ‏"‏ ‏.‏ وَفِي حَدِيثِ اللَّيْثِ وَابْنِ عُيَيْنَةَ ‏"‏ أَكُلَّ وَلَدِكَ ‏"‏ ‏.‏ وَرِوَايَةُ اللَّيْثِ عَنْ مُحَمَّدِ بْنِ النُّعْمَانِ وَحُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ أَنَّ بَشِيرًا جَاءَ بِالنُّعْمَانِ ‏.‏\hadithno{4179}\hadithtrans{This hadith has been narrated on the authority of Zuhri with different chains of transmitters and a slight variation of words}}
\hadithdefcmd{muslim}{4180}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، قَالَ حَدَّثَنَا النُّعْمَانُ بْنُ بَشِيرٍ، قَالَ وَقَدْ أَعْطَاهُ أَبُوهُ غُلاَمًا فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا هَذَا الْغُلاَمُ ‏"‏ ‏.‏ قَالَ أَعْطَانِيهِ أَبِي ‏.‏ قَالَ ‏"‏ فَكُلَّ إِخْوَتِهِ أَعْطَيْتَهُ كَمَا أَعْطَيْتَ هَذَا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَرُدَّهُ ‏"‏ ‏.‏\hadithno{4180}\hadithtrans{Nu'man b. Bashir reported that his father had donated a slave to him. Allah's Apostle (may peace he upon him) said:Who is this slave (how have you come to possess it)? Thereupon he (Nu'man b. Bashir) said: My father has donated it to me, whereupon he said: Have all brothers (of yours) been given this gift as given to you? He said: No. Thereupon he (the Holy Prophet) said: Then return him}}
\hadithdefcmd{muslim}{4181}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ حُصَيْنٍ، عَنِ الشَّعْبِيِّ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا أَبُو الأَحْوَصِ، عَنْ حُصَيْنٍ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ تَصَدَّقَ عَلَىَّ أَبِي بِبَعْضِ مَالِهِ فَقَالَتْ أُمِّي عَمْرَةُ بِنْتُ رَوَاحَةَ لاَ أَرْضَى حَتَّى تُشْهِدَ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَانْطَلَقَ أَبِي إِلَى النَّبِيِّ صلى الله عليه وسلم لِيُشْهِدَهُ عَلَى صَدَقَتِي فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفَعَلْتَ هَذَا بِوَلَدِكَ كُلِّهِمْ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ اتَّقُوا اللَّهَ وَاعْدِلُوا فِي أَوْلاَدِكُمْ ‏"‏ ‏.‏ فَرَجَعَ أَبِي فَرَدَّ تِلْكَ الصَّدَقَةَ ‏.‏\hadithno{4181}\hadithtrans{Nu'man b. Bashir reported:My father donated to me some of his property. My mother Amra bint Rawaha said: I shall not be pleased (with this act) until you make Allah's Messenger (ﷺ) a witness to it. My father went to Allah's Apostle (ﷺ) in order to make him the witness of the donation given to me. Allah's Messenger (ﷺ) said to him: Have you done the same with every son of yours? He said: No. Thereupon he (the Holy Prophet) said: Fear Allah, and observe equity in case of your children. My father returned and got back the gift}}
\hadithdefcmd{muslim}{4182}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ أَبِي حَيَّانَ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، ح. وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا أَبُو حَيَّانَ التَّيْمِيُّ، عَنِ الشَّعْبِيِّ، حَدَّثَنِي النُّعْمَانُ بْنُ بَشِيرٍ، أَنَّ أُمَّهُ بِنْتَ رَوَاحَةَ، سَأَلَتْ أَبَاهُ بَعْضَ الْمَوْهِبَةِ مِنْ مَالِهِ لاِبْنِهَا فَالْتَوَى بِهَا سَنَةً ثُمَّ بَدَا لَهُ فَقَالَتْ لاَ أَرْضَى حَتَّى تُشْهِدَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى مَا وَهَبْتَ لاِبْنِي ‏.‏ فَأَخَذَ أَبِي بِيَدِي وَأَنَا يَوْمَئِذٍ غُلاَمٌ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمَّ هَذَا بِنْتَ رَوَاحَةَ أَعْجَبَهَا أَنْ أُشْهِدَكَ عَلَى الَّذِي وَهَبْتُ لاِبْنِهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا بَشِيرُ أَلَكَ وَلَدٌ سِوَى هَذَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَقَالَ ‏"‏ أَكُلَّهُمْ وَهَبْتَ لَهُ مِثْلَ هَذَا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَلاَ تُشْهِدْنِي إِذًا فَإِنِّي لاَ أَشْهَدُ عَلَى جَوْرٍ ‏"‏ ‏.‏\hadithno{4182}\hadithtrans{Nu'man b. Bashir reported that his mother bint Rawaha asked his (Nu'man's) father about donating some gifts from his property to his son. He deferred the matter by one year, and then set forth to do that. She (Nu'man's mother) said:I shall not be pleased unless you call Allah's Messenger (ﷺ) as witness to what you confer as a gift on your son. (Nu'man said): So father took hold of my hand and I was at that time a boy, and came to Allah's Messenger (ﷺ). and said: Allah's Messenger, the mother of this son (of mine), daughter of Rawaha wishes that I should call you witness to what I confer as gift to her son. Allah's Messenger (may pease be upon him) said: Bashir, have you any other son besides this (son of yours)? He said: Yes. He (the Holy Prophet) said: Have you given gifts to all of them like this? He said: No. Thereupon he (the Holy Prophet) said: Then call me not as witness, for I cannot be witness to an injustice}}
\hadithdefcmd{muslim}{4183}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنِي أَبِي، حَدَّثَنَا إِسْمَاعِيلُ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَلَكَ بَنُونَ سِوَاهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَكُلَّهُمْ أَعْطَيْتَ مِثْلَ هَذَا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَلاَ أَشْهَدُ عَلَى جَوْرٍ ‏"‏ ‏.‏\hadithno{4183}\hadithtrans{Nu'man b. Bashir, reported that Allah's Messenger (ﷺ) had said:Have you, besides him, other sons? He said: Yes. Thereupon he (the Holy Prophet) said: Have you given gifts to all of them like this (as you have given to Nu'man)? He said: No. Thereupon he (the Holy Prophet) said: I cannot bear witness to an injustice}}
\hadithdefcmd{muslim}{4184}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لأَبِيهِ ‏ "‏ لاَ تُشْهِدْنِي عَلَى جَوْرٍ ‏"‏ ‏.‏\hadithno{4184}\hadithtrans{Nu'man b. Bashir (Allah be pleased with them) reported that Allah's Messenger (ﷺ) said to his father:Call me not as witness to an injustice}}
\hadithdefcmd{muslim}{4185}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، وَعَبْدُ الأَعْلَى، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ وَيَعْقُوبُ الدَّوْرَقِيُّ جَمِيعًا عَنِ ابْنِ عُلَيَّةَ، - وَاللَّفْظُ لِيَعْقُوبَ - قَالَ حَدَّثَنَا إِسْمَاعِيلُ، بْنُ إِبْرَاهِيمَ عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ انْطَلَقَ بِي أَبِي يَحْمِلُنِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ اشْهَدْ أَنِّي قَدْ نَحَلْتُ النُّعْمَانَ كَذَا وَكَذَا مِنْ مَالِي ‏.‏ فَقَالَ ‏"‏ أَكُلَّ بَنِيكَ قَدْ نَحَلْتَ مِثْلَ مَا نَحَلْتَ النُّعْمَانَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَأَشْهِدْ عَلَى هَذَا غَيْرِي - ثُمَّ قَالَ - أَيَسُرُّكَ أَنْ يَكُونُوا إِلَيْكَ فِي الْبِرِّ سَوَاءً ‏"‏ ‏.‏ قَالَ بَلَى ‏.‏ قَالَ ‏"‏ فَلاَ إِذًا ‏"‏ ‏.‏\hadithno{4185}\hadithtrans{Nu'man b. Bashir (Allah be pleased with them) reported:My father took me to Allah's Messenger (ﷺ) and said: Allah's Messenger, bear witness that I have given such and such gift to Nu'man from my property, whereupon he (the Holy Prophet) said: Have you conferred upon all of your sons as you have conferred upon Nu'man? He said: No. Thereupon he (the Holy Prophet) said: Call someone else besides me as a witness. And he further said: Would it, please you that they (your children) should all behave virtuously towards you? He said: Yes. He (the Holy Prophet) said: Then don't do that (i e. don't give gift to one to the exclusion of others)}}
\hadithdefcmd{muslim}{4186}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، حَدَّثَنَا أَزْهَرُ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ نَحَلَنِي أَبِي نُحْلاً ثُمَّ أَتَى بِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لِيُشْهِدَهُ فَقَالَ ‏"‏ أَكُلَّ وَلَدِكَ أَعْطَيْتَهُ هَذَا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ أَلَيْسَ تُرِيدُ مِنْهُمُ الْبِرَّ مِثْلَ مَا تُرِيدُ مِنْ ذَا ‏"‏ ‏.‏ قَالَ بَلَى ‏.‏ قَالَ ‏"‏ فَإِنِّي لاَ أَشْهَدُ ‏"‏ ‏.‏ قَالَ ابْنُ عَوْنٍ فَحَدَّثْتُ بِهِ مُحَمَّدًا فَقَالَ إِنَّمَا تَحَدَّثْنَا أَنَّهُ قَالَ ‏"‏ قَارِبُوا بَيْنَ أَوْلاَدِكُمْ ‏"‏ ‏.‏\hadithno{4186}\hadithtrans{Nu'man b. Bashir reported:My father conferred a gift upon me, and then brought me to Allah's Messenger (ﷺ) to make him a witness (to it). He (the Holy Prophet) said: Have you given such gift to every son of yours (as you have given to Nu'man)? He said: No. Thereupon he (the Holy Prophet) said: Don't you expect goodness from them as you expect from him? He said: Yes. of course. He (the Holy Prophet) said: I am not going to bear witness to it (as it is injustice). Ibn Aun (one of the narrators) said: I narrated this hadith to Muhammad (the other narrator) who said: Verily we narrated that lie (the Holy Prophet) had said: Observe equity amongst your children}}
\hadithdefcmd{muslim}{4187}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَتِ امْرَأَةُ بَشِيرٍ انْحَلِ ابْنِي غُلاَمَكَ وَأَشْهِدْ لِي رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ ابْنَةَ فُلاَنٍ سَأَلَتْنِي أَنْ أَنْحَلَ ابْنَهَا غُلاَمِي وَقَالَتْ أَشْهِدْ لِي رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَلَهُ إِخْوَةٌ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ أَفَكُلَّهُمْ أَعْطَيْتَ مِثْلَ مَا أَعْطَيْتَهُ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَلَيْسَ يَصْلُحُ هَذَا ‏.‏ وَإِنِّي لاَ أَشْهَدُ إِلاَّ عَلَى حَقٍّ ‏"‏ ‏.‏\hadithno{4187}\hadithtrans{Jabir (Allah be pleased with him) reported that the wife of Bashir said (to her husband):Give to my son your slave as a gift, and make for me Allah's Messenger (ﷺ) a witness He came to Allah's Messenger (ﷺ) and said: The daughter of so and so (his wife Amra bint Rawaha) asked me to give my slave as a gift to her son, and call for me Allah's Messenger (ﷺ) as a witness. Thereupon he (the Holy Prophet) said: Has he (Nu'man) brothers? He (Bashir) said: Yes. He (further) said: Have you given to all others as you have given to him? He said: No. He said: Then it is not fair; and verily I cannot bear witness but only to what is just}}
\hadithdefcmd{muslim}{4188}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ، عَبْدِ الرَّحْمَنِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا رَجُلٍ أُعْمِرَ عُمْرَى لَهُ وَلِعَقِبِهِ فَإِنَّهَا لِلَّذِي أُعْطِيَهَا لاَ تَرْجِعُ إِلَى الَّذِي أَعْطَاهَا لأَنَّهُ أَعْطَى عَطَاءً وَقَعَتْ فِيهِ الْمَوَارِيثُ ‏"‏ ‏.‏\hadithno{4188}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:"Any man who is given a gift for life, it belongs to him and his heirs. It belongs to the one to whom it is given, and does not go back to the one who gave it, because he has given it in such a way that it is subject to the rules of inheritance}}
\hadithdefcmd{muslim}{4189}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ أَعْمَرَ رَجُلاً عُمْرَى لَهُ وَلِعَقِبِهِ فَقَدْ قَطَعَ قَوْلُهُ حَقَّهُ فِيهَا وَهِيَ لِمَنْ أُعْمِرَ وَلِعَقِبِهِ ‏"‏ ‏.‏ غَيْرَ أَنَّ يَحْيَى قَالَ فِي أَوَّلِ حَدِيثِهِ ‏"‏ أَيُّمَا رَجُلٍ أُعْمِرَ عُمْرَى فَهِيَ لَهُ وَلِعَقِبِهِ ‏"‏ ‏\hadithno{4189}\hadithtrans{Jaber b. 'Abdullah (Allah be pleased with them) reported Allah's Messenger (may peace be upan him) as saying:He who conferred a life grant upon a person, it becomes his possession and that of his successors, for he surrendered his right in that by his declaration. (This property) now belongs to one to whom this lifelong grant has been made, and to his successors. Yahya narrated in the beginning of his narration: Whatever man is given a life grant, then it belongs to him and his posterity}}
\hadithdefcmd{muslim}{4190}{حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ الْعَبْدِيُّ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي ابْنُ شِهَابٍ، عَنِ الْعُمْرَى، وَسُنَّتِهَا، عَنْ حَدِيثِ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ جَابِرَ بْنَ عَبْدِ، اللَّهِ الأَنْصَارِيَّ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا رَجُلٍ أَعْمَرَ رَجُلاً عُمْرَى لَهُ وَلِعَقِبِهِ فَقَالَ قَدْ أَعْطَيْتُكَهَا وَعَقِبَكَ مَا بَقِيَ مِنْكُمْ أَحَدٌ ‏.‏ فَإِنَّهَا لِمَنْ أُعْطِيَهَا ‏.‏ وَإِنَّهَا لاَ تَرْجِعُ إِلَى صَاحِبِهَا مِنْ أَجْلِ أَنَّهُ أَعْطَى عَطَاءً وَقَعَتْ فِيهِ الْمَوَارِيثُ ‏"‏ ‏.‏\hadithno{4190}\hadithtrans{Jabir b. 'Abdullah al-Ansari (Allah be pleased with him) said:Allah's Messenger (ﷺ) said: Whoever a person conferred Umra (life grant) upon a person and he says: I confer upon you this and upon your descendants and anyone who survives you, and that becomes his possession and that of his posterity. It would become (a permanent possession) of those who were conferred upon this gift, and it would not return to its owner (donor), for he gave that as a gift in which accrued the right of inheritance}}
\hadithdefcmd{muslim}{4191}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لِعَبْدٍ - قَالاَ أَخْبَرَنَا عَبْدُ، الرَّزَّاقِ أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، قَالَ إِنَّمَا الْعُمْرَى الَّتِي أَجَازَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَقُولَ هِيَ لَكَ وَلِعَقِبِكَ ‏.‏ فَأَمَّا إِذَا قَالَ هِيَ لَكَ مَا عِشْتَ ‏.‏ فَإِنَّهَا تَرْجِعُ إِلَى صَاحِبِهَا ‏.‏ قَالَ مَعْمَرٌ وَكَانَ الزُّهْرِيُّ يُفْتِي بِهِ ‏.‏\hadithno{4191}\hadithtrans{Jabir (Allah be pleased with him) said:The Umra for which Allah's Messenger (ﷺ) gave sanction that a person way say: This (property) is for you and for your descendants. And when he said: That is for you as long as you live, then it will return to its owner (after the death of the donee). Ma'mar said: Zuhri used to give religious verdict according to this}}
\hadithdefcmd{muslim}{4192}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرٍ، - وَهُوَ ابْنُ عَبْدِ اللَّهِ - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِيمَنْ أُعْمِرَ عُمْرَى لَهُ وَلِعَقِبِهِ فَهِيَ لَهُ بَتْلَةً لاَ يَجُوزُ لِلْمُعْطِي فِيهَا شَرْطٌ وَلاَ ثُنْيَا ‏.‏ قَالَ أَبُو سَلَمَةَ لأَنَّهُ أَعْطَى عَطَاءً وَقَعَتْ فِيهِ الْمَوَارِيثُ فَقَطَعَتِ الْمَوَارِيثُ شَرْطَهُ ‏.‏\hadithno{4192}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with him) reported that Allah's Messenger (ﷺ) commanded that whoever is conferred upon a life grant along with his descendants is entitled to make use of the property conferred so long as he lives and his successors (also enjoy this privilege). That (property) becomes the their defect belonging. The donor cannot (after declaring Umra) lay down any condition or make any exception. Abu Salama said:For he conferred a grant and as such it becomes heritage. and the right of inheritance abrogated his condition}}
\hadithdefcmd{muslim}{4193}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعُمْرَى لِمَنْ وُهِبَتْ لَهُ ‏"‏ ‏.‏\hadithno{4193}\hadithtrans{Jabir (b. 'Abdullah) (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Life grant is for one upon whom it is bestowed}}
\hadithdefcmd{muslim}{4194}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي، كَثِيرٍ حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ بِمِثْلِهِ ‏.‏\hadithno{4194}\hadithtrans{Jabir b. 'Abdullah reported a hadith like this through another chain of transmitters}}
\hadithdefcmd{muslim}{4195}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، يَرْفَعُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{4195}\hadithtrans{Jabir reported this hadith directly from Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{4196}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمْسِكُوا عَلَيْكُمْ أَمْوَالَكُمْ وَلاَ تُفْسِدُوهَا فَإِنَّهُ مَنْ أَعْمَرَ عُمْرَى فَهِيَ لِلَّذِي أُعْمِرَهَا حَيًّا وَمَيِّتًا وَلِعَقِبِهِ ‏"‏ ‏.‏\hadithno{4196}\hadithtrans{Jabir (b. 'Abdullah) (Allah be pleased with him) reported Allah's Messenger (ﷺ) having said:Keep your property to yourselves and do not squander it, for he who conferred a life grant upon another that property will belong to him upon whom it is conferred whether he lives or dies, and (would pass on) to his successors (as heritage)}}
\hadithdefcmd{muslim}{4197}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا حَجَّاجُ بْنُ أَبِي عُثْمَانَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ وَكِيعٍ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، عَنْ أَيُّوبَ، كُلُّ هَؤُلاَءِ عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ أَبِي خَيْثَمَةَ وَفِي حَدِيثِ أَيُّوبَ مِنَ الزِّيَادَةِ قَالَ جَعَلَ الأَنْصَارُ يُعْمِرُونَ الْمُهَاجِرِينَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمْسِكُوا عَلَيْكُمْ أَمْوَالَكُمْ ‏"‏ ‏.‏\hadithno{4197}\hadithtrans{This hadith is narrated on the authority of Jabir through other chains of transmitters, but (with this addition of words) that thehadith transmitted on the authority of Ayyub (these words are found):" The Helpers (Ansar) conferred the benefit of 'Umra, upon the Emigrants (Muhajirin), whereupon Allah's Messenger (ﷺ) said: Keep your property to yourselves}}
\hadithdefcmd{muslim}{4198}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أَعْمَرَتِ امْرَأَةٌ بِالْمَدِينَةِ حَائِطًا لَهَا ابْنًا لَهَا ثُمَّ تُوُفِّيَ وَتُوُفِّيَتْ بَعْدَهُ وَتَرَكَتْ وَلَدًا وَلَهُ إِخْوَةٌ بَنُونَ لِلْمُعْمِرَةِ فَقَالَ وَلَدُ الْمُعْمِرَةِ رَجَعَ الْحَائِطُ إِلَيْنَا وَقَالَ بَنُو الْمُعْمَرِ بَلْ كَانَ لأَبِينَا حَيَاتَهُ وَمَوْتَهُ ‏.‏ فَاخْتَصَمُوا إِلَى طَارِقٍ مَوْلَى عُثْمَانَ فَدَعَا جَابِرًا فَشَهِدَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْعُمْرَى لِصَاحِبِهَا فَقَضَى بِذَلِكَ طَارِقٌ ثُمَّ كَتَبَ إِلَى عَبْدِ الْمَلِكِ فَأَخْبَرَهُ ذَلِكَ وَأَخْبَرَهُ بِشَهَادَةِ جَابِرٍ فَقَالَ عَبْدُ الْمَلِكِ صَدَقَ جَابِرٌ ‏.‏ فَأَمْضَى ذَلِكَ طَارِقٌ ‏.‏ فَإِنَّ ذَلِكَ الْحَائِطَ لِبَنِي الْمُعْمَرِ حَتَّى الْيَوْمِ ‏.‏\hadithno{4198}\hadithtrans{Jabir (Allah be pleased with him) reported that a woman gave her garden as a life grant to her son. He died and later on she also died and left a son behind and brothers also, The sons of the woman making life grant said (to those who had been conferred upon this 'Umra):This garden has returned to us. The sons of the one who had been given life grant said: This belonged to our father, during his lifetime and in case of his death. They took their dispute to Tariq, the freed slave of 'Uthman. He called Jabir and he gave testimony of Allah's Messenger (ﷺ) having said: Life grant belongs to one who is conferred upon this (privilege). Tariq gave this decision and then wrote to Abd al-Malik and informed him, Jabir bearing witness to it. Abd al-Malik said: Jabir has told the truth. Then Tariq gave a decree and, as a result thereof, it is to this day that the garden belongs to descendants of one who was conferred upon the life grant}}
\hadithdefcmd{muslim}{4199}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لأَبِي بَكْرٍ قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ أَبُو بَكْرٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ طَارِقًا، قَضَى بِالْعُمْرَى لِلْوَارِثِ لِقَوْلِ جَابِرِ بْنِ عَبْدِ اللَّهِ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4199}\hadithtrans{Sulaiman b. Yasir reported that Jabir gave this verdict. The inheritor has a right (to inherit) the life grant according to the statement of Jabir (b. 'Abdullah) (Allah be pleased with him) which he narrated from Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{4200}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى جَائِزَةٌ ‏"‏ ‏.‏\hadithno{4200}\hadithtrans{Jabir b. 'Abdullah reported Allah's Apostle (ﷺ) as saying:Life grant is permissible}}
\hadithdefcmd{muslim}{4201}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْعُمْرَى مِيرَاثٌ لأَهْلِهَا ‏"‏ ‏.‏\hadithno{4201}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported Allah's Apostle (ﷺ) as saying:Life grant is the heritage of one upon whom it is conferred}}
\hadithdefcmd{muslim}{4202}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى جَائِزَةٌ ‏"‏ ‏.‏\hadithno{4202}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:Life grant is permissible}}
\hadithdefcmd{muslim}{4203}{وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ ‏"‏ مِيرَاثٌ لأَهْلِهَا ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ جَائِزَةٌ ‏"‏ ‏.‏\hadithno{4203}\hadithtrans{This hadith is narrated on the authority of Qatada with the same chain of transmitters}}
